@@ -116,6 +116,15 @@ mpd_playlist_begin(const struct mpd_pair *pair);
 bool
 mpd_playlist_feed(struct mpd_playlist *playlist, const struct mpd_pair *pair);
 
+/**
+ * Obtain a list of stored playlists.
+ *
+ * @param connection the connection to MPD
+ * @return true on success, false on error
+ */
+bool
+mpd_send_list_playlists(struct mpd_connection *connection);
+
 /**
  * Receives the next playlist from the MPD server.
  *
